summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_tabs_module.cc
diff options
context:
space:
mode:
authoraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-24 19:59:41 +0000
committeraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-24 19:59:41 +0000
commit0ec9203dac6b11c664adda8a39b77f3f00eb6072 (patch)
tree65e5cff3f9e04da87e32e9436ddc795a7811c278 /chrome/browser/extensions/extension_tabs_module.cc
parent630d1b047c8c4ea54eef06fa24a89ad516457875 (diff)
downloadchromium_src-0ec9203dac6b11c664adda8a39b77f3f00eb6072.zip
chromium_src-0ec9203dac6b11c664adda8a39b77f3f00eb6072.tar.gz
chromium_src-0ec9203dac6b11c664adda8a39b77f3f00eb6072.tar.bz2
Generalize the ExtensionFunctionDispatcher::Delegate interface a bit more. In particular remove GetExtensionHost() and GetExtensionDOMUI(). I'm going to add a new type of EFD::Delegate soon that is neither of these, and I don't think it makes sense to have the code assume that EFD::Delegate must be one of the two of them.
Some code still does RTTI stuff through RenderViewHostDelegate::GetRenderViewType(), but in that case it is more clear that there are a long list of potential view types, and that the caller must be more careful. Review URL: http://codereview.chromium.org/1149003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@42519 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/extensions/extension_tabs_module.cc')
-rw-r--r--chrome/browser/extensions/extension_tabs_module.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/extensions/extension_tabs_module.cc b/chrome/browser/extensions/extension_tabs_module.cc
index 3d1ee4b..8afc4be 100644
--- a/chrome/browser/extensions/extension_tabs_module.cc
+++ b/chrome/browser/extensions/extension_tabs_module.cc
@@ -234,7 +234,7 @@ bool GetWindowFunction::RunImpl() {
}
bool GetCurrentWindowFunction::RunImpl() {
- Browser* browser = GetBrowser();
+ Browser* browser = GetCurrentBrowser();
if (!browser) {
error_ = keys::kNoCurrentWindowError;
return false;
@@ -312,10 +312,10 @@ bool CreateWindowFunction::RunImpl() {
// The call offsets the bounds by kWindowTilePixels (defined in WindowSizer to
// be 10)
//
// NOTE(rafaelw): It's ok if dispatcher_->GetBrowser() returns NULL here.
// GetBrowserWindowBounds will default to saved "default" values for the app.
WindowSizer::GetBrowserWindowBounds(std::wstring(), empty_bounds,
- GetBrowser(), &bounds,
+ GetCurrentBrowser(), &bounds,
&maximized);
Profile* window_profile = profile();
@@ -468,7 +468,7 @@ bool GetSelectedTabFunction::RunImpl() {
browser = GetBrowserInProfileWithId(profile(), window_id,
include_incognito(), &error_);
} else {
- browser = GetBrowser();
+ browser = GetCurrentBrowser();
if (!browser)
error_ = keys::kNoCurrentWindowError;
}
@@ -495,7 +495,7 @@ bool GetAllTabsInWindowFunction::RunImpl() {
browser = GetBrowserInProfileWithId(profile(), window_id,
include_incognito(), &error_);
} else {
- browser = GetBrowser();
+ browser = GetCurrentBrowser();
if (!browser)
error_ = keys::kNoCurrentWindowError;
}
@@ -520,7 +520,7 @@ bool CreateTabFunction::RunImpl() {
browser = GetBrowserInProfileWithId(profile(), window_id,
include_incognito(), &error_);
} else {
- browser = GetBrowser();
+ browser = GetCurrentBrowser();
if (!browser)
error_ = keys::kNoCurrentWindowError;
}
@@ -792,7 +792,7 @@ bool CaptureVisibleTabFunction::RunImpl() {
browser = GetBrowserInProfileWithId(profile(), window_id,
include_incognito(), &error_);
} else {
- browser = GetBrowser();
+ browser = GetCurrentBrowser();
}
if (!browser) {
@@ -910,7 +910,7 @@ bool DetectTabLanguageFunction::RunImpl() {
if (!browser || !contents)
return false;
} else {
- browser = GetBrowser();
+ browser = GetCurrentBrowser();
if (!browser)
return false;
contents = browser->tabstrip_model()->GetSelectedTabContents();
@@ -312,10 +312,10 @@ bool CreateWindowFunction::RunImpl() {
// be 10)
//
- // NOTE(rafaelw): It's ok if dispatcher_->GetBrowser() returns NULL here.
+ // NOTE(rafaelw): It's ok if GetCurrentBrowser() returns NULL here.
// GetBrowserWindowBounds will default to saved "default" values for the app.
WindowSizer::GetBrowserWindowBounds(std::wstring(), empty_bounds,